@@ -5,7 +5,7 @@ from jinja2 import Environment, FileSystemLoader
 
 from . import config
 
-__version__ = '0.0.4'
+__version__ = '0.0.6'
 
 APP_DIR = Path(__file__).parent
 INPUT_DIR = Path(config.INPUT_PATH)
@@ -15,7 +15,7 @@ IGNORE_ASSETS = set()
 
 jinja = Environment(
     loader=FileSystemLoader('input/templates', followlinks=True),
-    autoescape=jinja2.select_autoescape(),
+    autoescape=config.AUTOESCAPE,
 )
 
 def filter(f):
