@@ -12,9 +12,16 @@ logging.basicConfig(level=config.LOG_LEVEL, format=config.LOG_FORMAT)
 
 
 def run_generators():
+    modules = set()
     for file in (sssimp.APP_DIR / 'generators').glob('**/*.py'):
         module_str = path_strip(file).replace('/', '.')[:-len('.py')]
         module = importlib.import_module(f'.{module_str}', package='sssimp')
+        if hasattr(module, 'main'):
+            modules.add(module)
+        if hasattr(module, 'prepare'):
+            logging.info(f'Preparing {module.__name__}')
+            module.prepare()
+    for module in modules:
         logging.info(f'Running {module.__name__}')
         module.main()
 
