@@ -1,3 +1,5 @@
+from pathlib import Path
+
 from sssimp import APP_DIR
 
 def mkdir(path):
@@ -5,6 +7,7 @@ def mkdir(path):
     Creates a directory or the parent directory if `path` is not a directory.
     Safely ignores if already exists
     """
+    path = Path(path)
     if not path.is_dir():
         path = path.parent
     path.mkdir(exist_ok=True, parents=True)
